using System;
using System.Collections.Generic;
using Cpp2IlInjected;
using MEC;
using UnityEngine;
using UnityEngine.UI;

// Token: 0x0200027A RID: 634
[Token(Token = "0x200027A")]
public class UINavigationEffect : MonoBehaviour
{
	// Token: 0x17000104 RID: 260
	// (get) Token: 0x0600188B RID: 6283 RVA: 0x0003BC04 File Offset: 0x00039E04
	[Token(Token = "0x17000104")]
	public RectTransform Root
	{
		[Token(Token = "0x600188B")]
		[Address(RVA = "0x2B4380", Offset = "0x2B3180", VA = "0x1802B4380")]
		get
		{
			return this.root;
		}
	}

	// Token: 0x0600188C RID: 6284 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x600188C")]
	[Address(RVA = "0x10221A0", Offset = "0x1020FA0", VA = "0x1810221A0")]
	public void Appear()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x0600188D RID: 6285 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x600188D")]
	[Address(RVA = "0x10223B0", Offset = "0x10211B0", VA = "0x1810223B0")]
	public void Hide()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x0600188E RID: 6286 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x600188E")]
	[Address(RVA = "0x1022260", Offset = "0x1021060", VA = "0x181022260")]
	public void HideImmediate()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x0600188F RID: 6287 RVA: 0x0003BC18 File Offset: 0x00039E18
	[Token(Token = "0x600188F")]
	[Address(RVA = "0x10150E0", Offset = "0x1013EE0", VA = "0x1810150E0")]
	public void UpdateParent(Transform parent)
	{
		this.root.parentInternal = parent;
	}

	// Token: 0x06001890 RID: 6288 RVA: 0x0003BC38 File Offset: 0x00039E38
	[Token(Token = "0x6001890")]
	[Address(RVA = "0x767570", Offset = "0x766370", VA = "0x180767570")]
	public void UpdatePos(Vector2 anchoredPos)
	{
		this.root.anchoredPosition = anchoredPos;
	}

	// Token: 0x06001891 RID: 6289 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001891")]
	[Address(RVA = "0x1022730", Offset = "0x1021530", VA = "0x181022730")]
	public void UpdateArrowPos(UILabelHandler handler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001892 RID: 6290 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001892")]
	[Address(RVA = "0x10225E0", Offset = "0x10213E0", VA = "0x1810225E0")]
	public void UpdateArrowPos(UIMagicStatsHandler handler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001893 RID: 6291 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001893")]
	[Address(RVA = "0x1022460", Offset = "0x1021260", VA = "0x181022460")]
	private IEnumerator<float> ProcessFading(float value)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001894 RID: 6292 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001894")]
	[Address(RVA = "0x10224E0", Offset = "0x10212E0", VA = "0x1810224E0")]
	private void UpdateAlpha(float value)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001895 RID: 6293 RVA: 0x0003BC58 File Offset: 0x00039E58
	[Token(Token = "0x6001895")]
	[Address(RVA = "0x3088F0", Offset = "0x3076F0", VA = "0x1803088F0")]
	public UINavigationEffect()
	{
	}

	// Token: 0x0400228F RID: 8847
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x400228F")]
	[SerializeField]
	private RectTransform root;

	// Token: 0x04002290 RID: 8848
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x4002290")]
	[SerializeField]
	private MaskableGraphic[] icons;

	// Token: 0x04002291 RID: 8849
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x4002291")]
	private CoroutineHandle fadeProcessor;

	// Token: 0x04002292 RID: 8850
	[FieldOffset(Offset = "0x2C")]
	[Token(Token = "0x4002292")]
	private float alpha;
}
